require 'test_helper'

class SessionsControllerTest < ActionDispatch::IntegrationTest
  test "login" do
    get '/say/hello'
    assert_response :success
    assert_select 'legend', 'Login'
    assert_nil session[:user]

    post '/sessions/create', params: { email: users(:me).email, password: 'titok' }, headers: { 'HTTP_REFERER': '/say/hello' }
    assert_response :redirect
    assert_equal session[:user], users(:me).id
    follow_redirect!
    assert_select 'a', 'Profile'
  end

  test "invalid login" do
    get '/say/hello'
    assert_response :success
    assert_select 'legend', 'Login'
    assert_nil session[:user]

    post '/sessions/create', params: { email: users(:me).email, password: 'titok2' }, headers: { 'HTTP_REFERER': '/say/hello' }
    assert_response :redirect
    assert_nil session[:user]
    follow_redirect!
    assert_select 'a', 'Register'
  end

  test "logout" do
    get '/say/hello'
    assert_response :success
    assert_select 'legend', 'Login'
    assert_nil session[:user]

    post '/sessions/create', params: { email: users(:me).email, password: 'titok' }, headers: { 'HTTP_REFERER': '/say/hello' }
    assert_response :redirect
    assert_equal session[:user], users(:me).id
    follow_redirect!
    assert_select 'a', 'Profile'

    get '/sessions/destroy', headers: { 'HTTP_REFERER': '/say/hello' }
    assert_response :redirect
    assert_nil session[:user]
    follow_redirect!
    assert_select 'a', 'Register'
  end

end
